@@ -128,11 +128,6 @@ int QGeoMappingManager::managerVersion() const
     return d_ptr->engine->managerVersion();
 }
 
-QGeoCameraCapabilities QGeoMappingManager::cameraCapabilities() const
-{
-    return d_ptr->engine->cameraCapabilities();
-}
-
 /*!
     Returns a new QGeoMap instance which will be managed by this manager.
 */
@@ -193,6 +188,4 @@ QGeoMappingManagerPrivate::~QGeoMappingManagerPrivate()
     engine = 0;
 }
 
-#include "moc_qgeomappingmanager_p.cpp"
-
 QT_END_NAMESPACE
